translate.tools.pogrep

Package translate :: Package tools :: Module pogrep |
[hide private]
[frames] | no frames]

# Module pogrep

source code

Grep XLIFF, Gettext PO and TMX localization files

Matches are output to snippet files of the same type which can then be reviewed and later merged using pomerge

See: http://translate.sourceforge.net/wiki/toolkit/pogrep for examples and usage instructions

Classes | [hide private]
| GrepMatch Just a small data structure that represents a search match.
| GrepFilter
| GrepOptionParser a specialized Option Parser for the grep tool...

Functions | [hide private]
real_index(string, nfc_index) Calculate the real index in the unnormalized string that corresponds to the index nfc_index in the normalized string. | source code
find_matches(unit, part, strings, re_search) Return the GrepFilter objects where re_search matches in strings. | source code
rungrep(inputfile, outputfile, templatefile, checkfilter) reads in inputfile, filters using checkfilter, writes to outputfile | source code
cmdlineparser() | source code
main() | source code

Imports: factory, poheader, optrecurse, multistring, data, re, locale